@@ -201,10 +201,10 @@ class BaseLog:
                      dialog_type='out',
                      f_code=""):
         _, _, _, logger_module = self.get_current_location()
-        if len(request_content) > 3000:
-            request_content = request_content[:3000]
-        if len(response_content) > 3000:
-            response_content = response_content[:3000]
+        # if len(request_content) > 3000:
+        #     request_content = request_content[:3000]
+        # if len(response_content) > 3000:
+        #     response_content = response_content[:3000]
         data = {
             "app_name": self.journal_log_name,  # 服务编号
             "level": log_level,  # 日志界别
