@@ -1,6 +1,5 @@
 # coding:utf-8
 import json
-import threading
 import time
 import types
 import uuid
@@ -11,6 +10,38 @@ from LogCollectionFormatter.base_log import BaseLog
 from LogCollectionFormatter.insert_mq_tools import InsertQueue
 
 
+def check_resp_items(item):
+    """
+    递归检查嵌套字典中是否存在超长字符串
+    :param item:
+    :return:
+    """
+    try:
+        if not isinstance(item, dict):
+            item = json.loads(item)
+        if len(json.dumps(item, ensure_ascii=False)) <= 3000:
+            return item
+        else:
+            for key, value in item.items():
+                if isinstance(item[key], str):
+                    if item[key].__len__() > 1000:
+                        item[key] = None
+                elif isinstance(item[key], dict):
+                    item[key] = check_resp_items(item[key])
+                elif isinstance(item[key], list):
+                    item[key] = []
+                else:
+                    continue
+    except Exception as err:
+        print('日志参数处理异常 err=%s' % err)
+        if isinstance(item, (dict, str)):
+            if len(item) > 3000:
+                return item[:3000]
+            else:
+                return item
+    return item
+
+
 def ret_to_str(ret):
     if isinstance(ret, types.StringType):
         ret = ret
@@ -81,8 +112,6 @@ class MainLog(BaseLog):
                         total_time = str(int((end_time - begin_time) * 1000))
                         f_code = request.headers.get('User-Agent')
                         self.debug('with_internal_journallog() connection  after:%s', str(total_time))
-                        # 接口前置流水日志处理
-                        self.debug('%s Interface start,with param: %s', f.__name__, str(request.args))
                         action_code = f.__name__  # 接口操作码
                         request_url = request.url.encode('utf-8')
                         request_content = request.data
@@ -97,16 +126,10 @@ class MainLog(BaseLog):
                             transaction_id = str(uuid.uuid1()).replace("-", "")
                         # 接口后置流水日志处理
                         str_ret = ret_to_str(ret)
-                        self.debug('The Interface %s return: %s' % (f.__name__, str_ret))
                         if str_ret:
-                            if len(str_ret) > 3000:
-                                if not isinstance(str_ret, unicode):
-                                    str_ret = unicode(str_ret, 'utf-8')
-                                str_ret = str_ret[:3000]
-                        if request_length > 3000:
-                            if not isinstance(request_content, unicode):
-                                request_content = unicode(request_content, 'utf-8')
-                            request_content = request_content[:3000]
+                            str_ret = check_resp_items(str_ret)
+                        if request_content:
+                            request_content = check_resp_items(request_content)
                         response_content = str_ret
                         response_length = len(response_content)  # response正文长度
                         log_head_length = 80
